CancelableDebouncedVoidCallback class
Constructors
- CancelableDebouncedVoidCallback({required VoidCallback callback, Duration duration = const Duration(milliseconds: 300)})
Properties
- callback → VoidCallback
-
final
- duration → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
final
Methods
-
call(
) → void -
cancel(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited