InheritingScaffold class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- InheritingScaffold
Constructors
- InheritingScaffold({Key? key, bool? extendBody, bool? extendBodyBehindAppBar, PreferredSizeWidget? appBar, Widget? body, Widget? floatingActionButton, FloatingActionButtonLocation? floatingActionButtonLocation, FloatingActionButtonAnimator? floatingActionButtonAnimator, Widget? drawer, DrawerCallback? onDrawerChanged, Widget? endDrawer, DrawerCallback? onEndDrawerChanged, Color? drawerScrimColor, Color? backgroundColor, Widget? bottomSheet, bool? resizeToAvoidBottomInset, bool? primary, DragStartBehavior? drawerDragStartBehavior, double? drawerEdgeDragWidth, bool? drawerEnableOpenDragGesture, bool? endDrawerEnableOpenDragGesture})
-
const
Properties
- appBar → PreferredSizeWidget?
-
final
- backgroundColor → Color?
-
final
- body → Widget?
-
final
-
final
- bottomSheet → Widget?
-
final
- drawer → Widget?
-
final
- drawerDragStartBehavior → DragStartBehavior?
-
final
- drawerEdgeDragWidth → double?
-
final
- drawerEnableOpenDragGesture → bool?
-
final
- drawerScrimColor → Color?
-
final
- endDrawer → Widget?
-
final
- endDrawerEnableOpenDragGesture → bool?
-
final
- extendBody → bool?
-
final
- extendBodyBehindAppBar → bool?
-
final
- floatingActionButton → Widget?
-
final
- floatingActionButtonAnimator → FloatingActionButtonAnimator?
-
final
- floatingActionButtonLocation → FloatingActionButtonLocation?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onDrawerChanged → DrawerCallback?
-
final
- onEndDrawerChanged → DrawerCallback?
-
final
-
final
-
final
- primary → bool?
-
final
- propBehavior → ScaffoldBehavior
-
no setter
- resizeToAvoidBottomInset → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context, WidgetRef ref) → Widget - Describes the part of the user interface represented by this widget.
-
createElement(
) → _HookConsumerElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → _ConsumerState -
Creates the mutable state for this widget at a given location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited